==> hs-haskeline-0.6.4.0p0.tgz: lib/ghc/haskeline-0.6.4.0/register.sh <==
#!/bin/sh
echo 'name: haskeline
version: 0.6.4.0
id: haskeline-0.6.4.0-a52c6bc40980637f835cc0dba1706a57

license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://trac.haskell.org/haskeline
package-url:
description: Haskeline provides a user interface for line input in command-line
             programs.  This library is similar in purpose to readline, but since
             it is written in Haskell it is (hopefully) more easily used in other
             Haskell programs.
             .
             Haskeline runs both on POSIX-compatible systems and on Windows.
category: User Interfaces
author: Judah Jacobson
pkgpath: devel/hs-haskeline
exposed: True
exposed-modules: System.Console.Haskeline
                 System.Console.Haskeline.Completion
                 System.Console.Haskeline.Encoding
                 System.Console.Haskeline.MonadException
                 System.Console.Haskeline.History System.Console.Haskeline.IO
hidden-modules: System.Console.Haskeline.Backend.Terminfo
                System.Console.Haskeline.Backend.WCWidth
                System.Console.Haskeline.Backend.Posix
                System.Console.Haskeline.Backend.IConv
                System.Console.Haskeline.Backend.DumbTerm
                System.Console.Haskeline.Backend System.Console.Haskeline.Command
                System.Console.Haskeline.Command.Completion
                System.Console.Haskeline.Command.History
                System.Console.Haskeline.Command.KillRing
                System.Console.Haskeline.Directory System.Console.Haskeline.Emacs
                System.Console.Haskeline.InputT System.Console.Haskeline.Key
                System.Console.Haskeline.LineState System.Console.Haskeline.Monads
                System.Console.Haskeline.Prefs System.Console.Haskeline.RunCommand
                System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                System.Console.Haskeline.Vi
import-dirs: /usr/local/lib/ghc/haskeline-0.6.4.0
library-dirs: /usr/local/lib/ghc/haskeline-0.6.4.0
hs-libraries: HShaskeline-0.6.4.0
extra-libraries: iconv
extra-ghci-libraries:
include-dirs: /usr/local/lib/ghc/haskeline-0.6.4.0/include
includes: h_iconv.h
depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
         directory-1.1.0.0-ca04ddcf1c341deb4150c220bedd97c0
         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
         filepath-1.2.0.0-956a4b0c127b8c317f6cac3946b0b803
         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
         terminfo-0.3.1.3-625e05a736cbb633a33cc970d8f86595
         unix-2.4.2.0-41b8af27cfe8b819176ab06a4cb79133
         utf8-string-0.3.6-131bec5ed6c825184d560515f17820d3
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-haskeline-0.6.4.0/html/haskeline.haddock
haddock-html: /usr/local/share/doc/hs-haskeline-0.6.4.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-haskeline-0.6.4.7p1.tgz: lib/ghc/haskeline-0.6.4.7/register.sh <==
#!/bin/sh
echo 'name: haskeline
version: 0.6.4.7
id: haskeline-0.6.4.7-08f3dc18120deddd3fcdc27c5f52a01e

license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://trac.haskell.org/haskeline
package-url:
synopsis: A command-line interface for user input, written in Haskell.
description: Haskeline provides a user interface for line input in command-line
             programs.  This library is similar in purpose to readline, but since
             it is written in Haskell it is (hopefully) more easily used in other
             Haskell programs.
             .
             Haskeline runs both on POSIX-compatible systems and on Windows.
category: User Interfaces
author: Judah Jacobson
pkgpath: devel/hs-haskeline
exposed: True
exposed-modules: System.Console.Haskeline
                 System.Console.Haskeline.Completion
                 System.Console.Haskeline.Encoding
                 System.Console.Haskeline.MonadException
                 System.Console.Haskeline.History System.Console.Haskeline.IO
hidden-modules: System.Console.Haskeline.Backend.Terminfo
                System.Console.Haskeline.Backend.WCWidth
                System.Console.Haskeline.Backend.Posix
                System.Console.Haskeline.Backend.IConv
                System.Console.Haskeline.Backend.DumbTerm
                System.Console.Haskeline.Backend System.Console.Haskeline.Command
                System.Console.Haskeline.Command.Completion
                System.Console.Haskeline.Command.History
                System.Console.Haskeline.Command.KillRing
                System.Console.Haskeline.Directory System.Console.Haskeline.Emacs
                System.Console.Haskeline.InputT System.Console.Haskeline.Key
                System.Console.Haskeline.LineState System.Console.Haskeline.Monads
                System.Console.Haskeline.Prefs System.Console.Haskeline.RunCommand
                System.Console.Haskeline.Term System.Console.Haskeline.Command.Undo
                System.Console.Haskeline.Vi
trusted: False
import-dirs: /usr/local/lib/ghc/haskeline-0.6.4.7
library-dirs: /usr/local/lib/ghc/haskeline-0.6.4.7
hs-libraries: HShaskeline-0.6.4.7
extra-libraries: iconv
extra-ghci-libraries:
include-dirs: /usr/local/lib/ghc/haskeline-0.6.4.7/include
includes: h_iconv.h
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
         terminfo-0.3.1.3-e63a5289027696968365d5f466f316a6
         unix-2.5.1.1-0adea5be633a6b5a124519287d54626d
         utf8-string-0.3.8-2777416918ab74e3e486858d8ef2fdf6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-haskeline-0.6.4.7/html/haskeline.haddock
haddock-html: /usr/local/share/doc/hs-haskeline-0.6.4.7/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
